@@ -268,7 +268,7 @@ class TrackMeHandlerSplkDhmRead_v2(trackme_rest_handler.RESTHandler):
                     entity_searches.get("splk_dhm_overview_pie_root_search")
                 )
                 entity_info["splk_dhm_overview_trackme_pie_root_search"] = (
-                    f'| mstats latest(trackme.splk_dhm.last_eventcount) as count where `trackme_metrics_idx({tenant_id})` tenant_id="{tenant_id}" object_category="splk-dhm" object="{object_value}" by object, idx, st | rename idx as index, st as sourcetype'
+                    f'| mstats latest(trackme.splk_dhm.last_eventcount) as count where `trackme_metrics_idx({tenant_id})` tenant_id="{tenant_id}" object_category="splk-dhm" object_id="{key}" by object, idx, st | rename idx as index, st as sourcetype | where [ | inputlookup trackme_dhm_tenant_{tenant_id} where _key="{key}" | table data_index, data_sourcetype | eval data_index=split(data_index, ","), data_sourcetype=split(data_sourcetype, ",") | rename data_index as index, data_sourcetype as sourcetype | format | return $search ]'
                 )
 
                 # timechart view
